.. jira-python documentation main file, created by
   sphinx-quickstart on Thu May  3 17:01:50 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Python Jira
###########
Python library to work with Jira APIs

.. toctree::
    :numbered:

    installation
    examples
    jirashell
    advanced
    contributing
    api

This documents the ``jira`` python package (version |release|), a Python library designed to ease the use of the
Jira REST API. Some basic support for the GreenHopper REST API also exists.

Documentation is also available in
`Dash
<dash-feed://https%3A%2F%2Fjira.readthedocs.io%2Fen%2Flatest%2Fjira.xml>`_ format.



The source is stored at https://github.com/pycontribs/jira.

Until someone will find a better way to generate the release notes you can read
https://github.com/pycontribs/jira/blob/main/CHANGELOG which is generated based on git commit messages.

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
